# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: client_tester.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63lient_tester.proto\x12\rclient_tester\"|\n\x0bTestRequest\x12\x0e\n\x06\x66\x61\x63tor\x18\x01 \x01(\x05\x12\x10\n\x08readings\x18\x02 \x03(\x02\x12\x0c\n\x04uuid\x18\x03 \x01(\x04\x12\x13\n\x0bsample_flag\x18\x04 \x01(\x08\x12\x14\n\x0crequest_name\x18\x05 \x01(\t\x12\x12\n\nextra_data\x18\x06 \x03(\x0c\"1\n\x0cTestResponse\x12\x0f\n\x07\x61verage\x18\x01 \x01(\x01\x12\x10\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x02 \x01(\t2\xce\x02\n\x0c\x43lientTester\x12K\n\x0eTestUnaryUnary\x12\x1a.client_tester.TestRequest\x1a\x1b.client_tester.TestResponse\"\x00\x12N\n\x0fTestUnaryStream\x12\x1a.client_tester.TestRequest\x1a\x1b.client_tester.TestResponse\"\x00\x30\x01\x12N\n\x0fTestStreamUnary\x12\x1a.client_tester.TestRequest\x1a\x1b.client_tester.TestResponse\"\x00(\x01\x12Q\n\x10TestStreamStream\x12\x1a.client_tester.TestRequest\x1a\x1b.client_tester.TestResponse\"\x00(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'client_tester_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TESTREQUEST']._serialized_start=38
  _globals['_TESTREQUEST']._serialized_end=162
  _globals['_TESTRESPONSE']._serialized_start=164
  _globals['_TESTRESPONSE']._serialized_end=213
  _globals['_CLIENTTESTER']._serialized_start=216
  _globals['_CLIENTTESTER']._serialized_end=550
# @@protoc_insertion_point(module_scope)
